Extra Race

Afficher ou masquer le menu mobile

## À propos

### Quand la course à pied pète les plombs !

Des sapins, encore des sapins, de l’eau, des montées, des descentes et surtout plein d’obstacles et d’ateliers, certains ludiques, d’autres vraiment fun et enfin, certains qui vous donneront du fil à retordre.

L’Extra Race Beaujolais Vert, nichée au cœur du Beaujolais vert (c’est fou comme le nom est bien trouvé) se veut nature et sportive. Nichée au cœur d’un écrin de verdure à seulement 1h00 de Lyon, un dépaysement total et assuré le temps d’un jour ou d’un week-end qui sait ?

Lire la suite

## Le 1 mai 2016

### Soyez prêts pour le prochain départ

Inscrivez-vous

## Actualités

- 2 novembre 2015

  ### L’Extra Race Beaujolais Vert 2016 est lancée

  Lire la suite

- 29 septembre 2015

  ### Extra Race 2015 – les photos participants

  Lire la suite

- 28 septembre 2015

  ### Extra Race, Extra Cool,

  Lire la suite

## Les parcours

### Découvrez tous les parcours sur la carte

### Publicité

Aller à la barre d’outils